==> mathjs-1.5.0.jar: META-INF/resources/webjars/mathjs/1.5.0/docs/reference/functions/alphabetical.md <==
# Function reference (alphabetical)

- [abs(x)](abs.md)
- [acos(x)](acos.md)
- [acosh(x)](acosh.md)
- [acot(x)](acot.md)
- [acoth(x)](acoth.md)
- [acsc(x)](acsc.md)
- [acsch(x)](acsch.md)
- [add(x, y)](add.md)
- [and(x, y)](and.md)
- [arg(x)](arg.md)
- [asec(x)](asec.md)
- [asech(x)](asech.md)
- [asin(x)](asin.md)
- [asinh(x)](asinh.md)
- [atan(x)](atan.md)
- [atan2(y, x)](atan2.md)
- [atanh(x)](atanh.md)
- [bignumber(x)](bignumber.md)
- [bitAnd(x, y)](bitAnd.md)
- [bitNot(x)](bitNot.md)
- [bitOr(x, y)](bitOr.md)
- [bitXor(x, y)](bitXor.md)
- [boolean(x)](boolean.md)
- [ceil(x)](ceil.md)
- [chain(value)](chain.md)
- [clone(x)](clone.md)
- [combinations(n, k)](combinations.md)
- [compare(x, y)](compare.md)
- [compile(expr)](compile.md)
- [complex(re, im)](complex.md)
- [concat(a, b, c, ... [, dim])](concat.md)
- [conj(x)](conj.md)
- [cos(x)](cos.md)
- [cosh(x)](cosh.md)
- [cot(x)](cot.md)
- [coth(x)](coth.md)
- [cross(x, y)](cross.md)
- [csc(x)](csc.md)
- [csch(x)](csch.md)
- [cube(x)](cube.md)
- [deepEqual(x, y)](deepEqual.md)
- [det(x)](det.md)
- [diag(X)](diag.md)
- [distribution(name)](distribution.md)
- [divide(x, y)](divide.md)
- [dot(x, y)](dot.md)
- [dotDivide(x, y)](dotDivide.md)
- [dotMultiply(x, y)](dotMultiply.md)
- [dotPow(x, y)](dotPow.md)
- [equal(x, y)](equal.md)
- [eval(expr [, scope])](eval.md)
- [exp(x)](exp.md)
- [eye(n)](eye.md)
- [factorial(n)](factorial.md)
- [filter(x, test)](filter.md)
- [fix(x)](fix.md)
- [flatten(x)](flatten.md)
- [floor(x)](floor.md)
- [forEach(x, callback)](forEach.md)
- [format(value [, precision])](format.md)
- [gamma(n)](gamma.md)
- [gcd(a, b)](gcd.md)
- [help(search)](help.md)
- [im(x)](im.md)
- [import(filename | object, override)](import.md)
- [index(range1, range2, ...)](index.md)
- [inv(x)](inv.md)
- [larger(x, y)](larger.md)
- [largerEq(x, y)](largerEq.md)
- [lcm(a, b)](lcm.md)
- [leftShift(x, y)](leftShift.md)
- [log(x [, base])](log.md)
- [log10(x)](log10.md)
- [map(x, callback)](map.md)
- [matrix(x)](matrix.md)
- [max(a, b, c, ...)](max.md)
- [mean(a, b, c, ...)](mean.md)
- [median(a, b, c, ...)](median.md)
- [min(a, b, c, ...)](min.md)
- [mod(x, y)](mod.md)
- [multiply(x, y)](multiply.md)
- [norm(x [, p])](norm.md)
- [not(x)](not.md)
- [nthRoot(a, root)](nthRoot.md)
- [number(value)](number.md)
- [ones(m, n, p, ...)](ones.md)
- [or(x, y)](or.md)
- [parse(expr [, scope])](parse.md)
- [parser()](parser.md)
- [permutations(n)](permutations.md)
- [pickRandom(array)](pickRandom.md)
- [pow(x, y)](pow.md)
- [print(template, values [, precision])](print.md)
- [prod(a, b, c, ...)](prod.md)
- [random([min, max])](random.md)
- [randomInt([min, max])](randomInt.md)
- [range(start, end [, step])](range.md)
- [re(x)](re.md)
- [resize(x, size [, defaultValue])](resize.md)
- [rightArithShift(x, y)](rightArithShift.md)
- [rightLogShift(x, y)](rightLogShift.md)
- [round(x [, n])](round.md)
- [sec(x)](sec.md)
- [sech(x)](sech.md)
- [sign(x)](sign.md)
- [sin(x)](sin.md)
- [sinh(x)](sinh.md)
- [size(x)](size.md)
- [smaller(x, y)](smaller.md)
- [smallerEq(x, y)](smallerEq.md)
- [sort(x)](sort.md)
- [sqrt(x)](sqrt.md)
- [square(x)](square.md)
- [squeeze(x)](squeeze.md)
- [std(a, b, c, ...)](std.md)
- [string(value)](string.md)
- [subset(x, index [, replacement])](subset.md)
- [subtract(x, y)](subtract.md)
- [sum(a, b, c, ...)](sum.md)
- [tan(x)](tan.md)
- [tanh(x)](tanh.md)
- [to(x, unit)](to.md)
- [trace(x)](trace.md)
- [transpose(x)](transpose.md)
- [typeof(x)](typeof.md)
- [unaryMinus(x)](unaryMinus.md)
- [unaryPlus(x)](unaryPlus.md)
- [unequal(x, y)](unequal.md)
- [unit(x)](unit.md)
- [var(a, b, c, ...)](var.md)
- [xgcd(a, b)](xgcd.md)
- [xor(x, y)](xor.md)
- [zeros(m, n, p, ...)](zeros.md)

==> mathjs-2.2.0.jar: META-INF/resources/webjars/mathjs/2.2.0/docs/reference/functions/alphabetical.md <==
# Function reference (alphabetical)

- [abs(x)](abs.md)
- [acos(x)](acos.md)
- [acosh(x)](acosh.md)
- [acot(x)](acot.md)
- [acoth(x)](acoth.md)
- [acsc(x)](acsc.md)
- [acsch(x)](acsch.md)
- [add(x, y)](add.md)
- [and(x, y)](and.md)
- [arg(x)](arg.md)
- [asec(x)](asec.md)
- [asech(x)](asech.md)
- [asin(x)](asin.md)
- [asinh(x)](asinh.md)
- [atan(x)](atan.md)
- [atan2(y, x)](atan2.md)
- [atanh(x)](atanh.md)
- [bellNumbers(n)](bellNumbers.md)
- [bignumber(x)](bignumber.md)
- [bitAnd(x, y)](bitAnd.md)
- [bitNot(x)](bitNot.md)
- [bitOr(x, y)](bitOr.md)
- [bitXor(x, y)](bitXor.md)
- [boolean(x)](boolean.md)
- [catalan(n)](catalan.md)
- [ceil(x)](ceil.md)
- [chain(value)](chain.md)
- [clone(x)](clone.md)
- [combinations(n, k)](combinations.md)
- [compare(x, y)](compare.md)
- [compile(expr)](compile.md)
- [complex(re, im)](complex.md)
- [composition(n, k)](composition.md)
- [concat(a, b, c, ... [, dim])](concat.md)
- [conj(x)](conj.md)
- [cos(x)](cos.md)
- [cosh(x)](cosh.md)
- [cot(x)](cot.md)
- [coth(x)](coth.md)
- [cross(x, y)](cross.md)
- [csc(x)](csc.md)
- [csch(x)](csch.md)
- [cube(x)](cube.md)
- [deepEqual(x, y)](deepEqual.md)
- [det(x)](det.md)
- [diag(X)](diag.md)
- [distribution(name)](distribution.md)
- [divide(x, y)](divide.md)
- [dot(x, y)](dot.md)
- [dotDivide(x, y)](dotDivide.md)
- [dotMultiply(x, y)](dotMultiply.md)
- [dotPow(x, y)](dotPow.md)
- [equal(x, y)](equal.md)
- [eval(expr [, scope])](eval.md)
- [exp(x)](exp.md)
- [eye(n)](eye.md)
- [factorial(n)](factorial.md)
- [filter(x, test)](filter.md)
- [fix(x)](fix.md)
- [flatten(x)](flatten.md)
- [floor(x)](floor.md)
- [forEach(x, callback)](forEach.md)
- [format(value [, precision])](format.md)
- [fraction(numerator, denominator)](fraction.md)
- [gamma(n)](gamma.md)
- [gcd(a, b)](gcd.md)
- [help(search)](help.md)
- [im(x)](im.md)
- [intersect(endPoint1Line1, endPoint2Line1, endPoint1Line2, endPoint2Line2)](intersect.md)
- [inv(x)](inv.md)
- [isInteger(x)](isInteger.md)
- [isNegative(x)](isNegative.md)
- [isNumeric(x)](isNumeric.md)
- [isPositive(x)](isPositive.md)
- [isZero(x)](isZero.md)
- [kldivergence(x, y)](kldivergence.md)
- [larger(x, y)](larger.md)
- [largerEq(x, y)](largerEq.md)
- [lcm(a, b)](lcm.md)
- [leftShift(x, y)](leftShift.md)
- [log(x [, base])](log.md)
- [log10(x)](log10.md)
- [lsolve(L, b)](lsolve.md)
- [lup(A)](lup.md)
- [lusolve(A, b)](lusolve.md)
- [map(x, callback)](map.md)
- [matrix(x)](matrix.md)
- [max(a, b, c, ...)](max.md)
- [mean(a, b, c, ...)](mean.md)
- [median(a, b, c, ...)](median.md)
- [min(a, b, c, ...)](min.md)
- [mod(x, y)](mod.md)
- [mode(a, b, c, ...)](mode.md)
- [multinomial(a)](multinomial.md)
- [multiply(x, y)](multiply.md)
- [norm(x [, p])](norm.md)
- [not(x)](not.md)
- [nthRoot(a)](nthRoot.md)
- [number(value)](number.md)
- [ones(m, n, p, ...)](ones.md)
- [or(x, y)](or.md)
- [parse(expr [, scope])](parse.md)
- [parser()](parser.md)
- [partitionSelect(x, k)](partitionSelect.md)
- [permutations(n [, k])](permutations.md)
- [pickRandom(array)](pickRandom.md)
- [pow(x, y)](pow.md)
- [print(template, values [, precision])](print.md)
- [prod(a, b, c, ...)](prod.md)
- [quantileSeq(A, prob[, sorted])](quantileSeq.md)
- [random([min, max])](random.md)
- [randomInt([min, max])](randomInt.md)
- [range(start, end [, step])](range.md)
- [re(x)](re.md)
- [resize(x, size [, defaultValue])](resize.md)
- [rightArithShift(x, y)](rightArithShift.md)
- [rightLogShift(x, y)](rightLogShift.md)
- [round(x [, n])](round.md)
- [sec(x)](sec.md)
- [sech(x)](sech.md)
- [sign(x)](sign.md)
- [sin(x)](sin.md)
- [sinh(x)](sinh.md)
- [size(x)](size.md)
- [slu(A, order, threshold)](slu.md)
- [smaller(x, y)](smaller.md)
- [smallerEq(x, y)](smallerEq.md)
- [sort(x)](sort.md)
- [sqrt(x)](sqrt.md)
- [square(x)](square.md)
- [squeeze(x)](squeeze.md)
- [std(a, b, c, ...)](std.md)
- [stirlingS2(n, k)](stirlingS2.md)
- [string(value)](string.md)
- [subset(x, index [, replacement])](subset.md)
- [subtract(x, y)](subtract.md)
- [sum(a, b, c, ...)](sum.md)
- [tan(x)](tan.md)
- [tanh(x)](tanh.md)
- [to(x, unit)](to.md)
- [trace(x)](trace.md)
- [transpose(x)](transpose.md)
- [typeof(x)](typeof.md)
- [unaryMinus(x)](unaryMinus.md)
- [unaryPlus(x)](unaryPlus.md)
- [unequal(x, y)](unequal.md)
- [unit(x)](unit.md)
- [usolve(U, b)](usolve.md)
- [var(a, b, c, ...)](var.md)
- [xgcd(a, b)](xgcd.md)
- [xor(x, y)](xor.md)
- [zeros(m, n, p, ...)](zeros.md)
